@@ -1,9 +1,9 @@
-# SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
+# SPDX-FileCopyrightText: 2017-2023 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
 import logging
 import os
-from typing import Optional, Union
+from typing import Optional, Union, Tuple
 
 import pandas as pd
 import structlog
@@ -31,6 +31,8 @@ MAXIMUM_MODEL_AGE: int = 7
 DEFAULT_EARLY_STOPPING_ROUNDS: int = 10
 PENALTY_FACTOR_OLD_MODEL: float = 1.2
 
+logger = structlog.get_logger(__name__)
+
 
 def train_model_pipeline(
     pj: PredictionJobDataClass,
@@ -60,27 +62,12 @@ def train_model_pipeline(
 
     """
     # Initialize logger and serializer
-    logger = structlog.get_logger(__name__)
     serializer = MLflowSerializer(mlflow_tracking_uri=mlflow_tracking_uri)
 
     # Get old model and age
-    try:
-        old_model, model_specs = serializer.load_model(experiment_name=str(pj["id"]))
-        old_model_age = old_model.age  # Age attribute is openstef specific
-    except (AttributeError, FileNotFoundError, LookupError):
-        old_model = None
-        old_model_age = float("inf")
-        if pj["default_modelspecs"] is not None:
-            model_specs = pj["default_modelspecs"]
-            if model_specs.id != pj.id:
-                raise RuntimeError(
-                    "The id of the prediction job and its default model_specs do not"
-                    " match."
-                )
-        else:
-            # create basic model_specs
-            model_specs = ModelSpecificationDataClass(id=pj["id"])
-        logger.warning("No old model found, training new model", pid=pj["id"])
+    old_model, model_specs, old_model_age = train_pipeline_step_load_model(
+        pj, serializer
+    )
 
     # Check old model age and continue yes/no
     if (old_model_age < MAXIMUM_MODEL_AGE) and check_old_model_age:
@@ -189,7 +176,14 @@ def train_model_pipeline_core(
     logger = structlog.get_logger(__name__)
 
     # Call common pipeline
-    model, report, train_data, validation_data, test_data = train_pipeline_common(
+    (
+        model,
+        report,
+        train_data,
+        validation_data,
+        test_data,
+        operational_score_data,
+    ) = train_pipeline_common(
         pj,
         model_specs,
         input_data,
@@ -205,8 +199,8 @@ def train_model_pipeline_core(
             combined = combined.iloc[:, :-1]
 
         x_data, y_data = (
-            combined.iloc[:, 1:-1],
-            combined.iloc[:, 0],
+            operational_score_data.iloc[:, 1:-1],
+            operational_score_data.iloc[:, 0],
         )
 
         # Score method always returns R^2
@@ -273,7 +267,12 @@ def train_pipeline_common(
         horizons=horizons,
     )
 
-    train_data, validation_data, test_data = train_pipeline_step_split_data(
+    (
+        train_data,
+        validation_data,
+        test_data,
+        operational_score_data,
+    ) = train_pipeline_step_split_data(
         data_with_features=data_with_features,
         pj=pj,
         test_fraction=test_fraction,
@@ -289,7 +288,7 @@ def train_pipeline_common(
     )
 
     # Report about the training process
-    reporter = Reporter(train_data, validation_data, test_data)
+    reporter = Reporter(train_data, validation_data, test_data, pj.quantiles)
     report = reporter.generate_report(model)
 
     if pj.save_train_forecasts:
@@ -297,7 +296,34 @@ def train_pipeline_common(
         validation_data["forecast"] = model.predict(validation_data.iloc[:, 1:-1])
         test_data["forecast"] = model.predict(test_data.iloc[:, 1:-1])
 
-    return model, report, train_data, validation_data, test_data
+    return model, report, train_data, validation_data, test_data, operational_score_data
+
+
+def train_pipeline_step_load_model(
+    pj: PredictionJobDataClass, serializer: MLflowSerializer
+) -> tuple[OpenstfRegressor, ModelSpecificationDataClass, Union[int, float]]:
+    try:
+        old_model, model_specs = serializer.load_model(experiment_name=str(pj.id))
+        old_model_age = old_model.age  # Age attribute is openstef specific
+        return old_model, model_specs, old_model_age
+    except (AttributeError, FileNotFoundError, LookupError):
+        logger.warning("No old model found, training new model", pid=pj.id)
+    except Exception:
+        logger.exception("Old model could not be loaded, training new model", pid=pj.id)
+    old_model = None
+    old_model_age = float("inf")
+    if pj["default_modelspecs"] is not None:
+        model_specs = pj["default_modelspecs"]
+        if model_specs.id != pj.id:
+            raise RuntimeError(
+                "The id of the prediction job and its default model_specs do not"
+                " match."
+            )
+    else:
+        # create basic model_specs
+        model_specs = ModelSpecificationDataClass(id=pj["id"])
+
+    return old_model, model_specs, old_model_age
 
 
 def train_pipeline_step_compute_features(
@@ -501,7 +527,7 @@ def train_pipeline_step_split_data(
             required_arguments=["data", "test_fraction"]
         )
 
-    train_data, validation_data, test_data = split_func(
+    train_data, validation_data, test_data, operational_score_data = split_func(
         data_with_features, test_fraction, **split_args
     )
 
@@ -509,4 +535,4 @@ def train_pipeline_step_split_data(
     if not test_data_predefined.empty:
         test_data = test_data_predefined
 
-    return train_data, validation_data, test_data
+    return train_data, validation_data, test_data, operational_score_data
